#include <kos.h>
#include <SDL/SDL.h>
#include <SDL/SDL_mixer.h>
#include <SDL/SDL_image.h>
#include "storm.h"

/* Fading surfaces */
SDL_Surface* intro_img1, * intro_img2, * intro_img3;
SDL_Surface* fscreen;
SDL_Rect dest;

Mix_Music * stormfx;

void fade_screen(SDL_Surface *Surface)
{
/* Note:  This fading process is really slow when the display cannot
          allocate all of the requested colors, i.e. warp_colors isn't
          set in SDL_SetColors()
*/
        SDL_Palette *palette;
        SDL_Color *orig_colors;
        SDL_Color *fade_colors;
        int ncolors, i;

        /* Get the current colormap */
        palette = Surface->format->palette;
        if ( palette == NULL ) {        /* The display is not palettized */
                return;
        }
        ncolors = palette->ncolors;
        orig_colors = (SDL_Color *)malloc(ncolors*sizeof(SDL_Color));
        fade_colors = (SDL_Color *)malloc(ncolors*sizeof(SDL_Color));
        memcpy(orig_colors, palette->colors, ncolors*sizeof(SDL_Color));

        /* Copy the original colors to the faded colors */
        memcpy(fade_colors, orig_colors, ncolors*sizeof(SDL_Color));

        /* Fade the colormap to black and back
           Note: A more sophisticated fading routine would detect the speed
                 of the palette change and base the number of fading steps 
                 on that to provide a consistent fade time on all displays.
        */
        for ( i=32-1; i>=0; --i ) {     /* 32 step fade out */
                int c;
                for ( c=0; c<ncolors; ++c ) {
                        fade_colors[c].r = ((int)orig_colors[c].r*i)/32;
                        fade_colors[c].g = ((int)orig_colors[c].g*i)/32;
                        fade_colors[c].b = ((int)orig_colors[c].b*i)/32;
                }
                SDL_SetColors(Surface, fade_colors, 0, ncolors);
        }
        for ( i=0; i<32; ++i ) {        /* 32 step fade in */
                int c;
                for ( c=0; c<ncolors; ++c ) {
                        fade_colors[c].r = ((int)orig_colors[c].r*i)/32;
                        fade_colors[c].g = ((int)orig_colors[c].g*i)/32;
                        fade_colors[c].b = ((int)orig_colors[c].b*i)/32;
                }
                SDL_SetColors(Surface, fade_colors, 0, ncolors);
        }
        free(orig_colors);
        free(fade_colors);
        return;
}

void do_intro()
{
  Mix_OpenAudio(22050, AUDIO_U8, 1, 512);
  fscreen = SDL_SetVideoMode (640, 480, 32,SDL_ANYFORMAT|SDL_FULLSCREEN);

  intro_img1 = SDL_DisplayFormat (IMG_Load("/rd/storm/disclaimer.png")) ;
  intro_img2 = SDL_DisplayFormat (IMG_Load("/rd/storm/storm_intro.png")) ;
  intro_img3 = SDL_DisplayFormat (IMG_Load ("/rd/storm/SDL_title.png")) ;
  stormfx = Mix_LoadMUS("/rd/storm/stormfx.wav");

  SDL_BlitSurface(intro_img1, NULL, fscreen, NULL);
  SDL_UpdateRect(fscreen, 0, 0, 640, 480);
  SDL_Delay (4000) ;
  SDL_BlitSurface(intro_img2, NULL, fscreen, NULL);
  SDL_UpdateRect(fscreen, 0, 0, 640, 480);
  Mix_PlayMusic(stormfx, 0);
  SDL_Delay (5000) ;
  SDL_BlitSurface(intro_img3, NULL, fscreen, NULL);
  SDL_UpdateRect(fscreen, 0, 0, 640, 480);
  SDL_Delay (4000);
}

void vmu_lcd_update()
{
vmu_set_icon(vmu_icon_xpm);
}

